==> debci_1.2.tar.xz: debci-1.2/spec/debci/package_spec.rb <==
require 'debci/package'
require 'debci/status'

describe Debci::Package do

  let(:repository) { double }

  let(:package) do
    Debci::Package.new('rake', repository)
  end

  it 'queries repository for architectures' do
    expect(repository).to receive(:architectures_for).with(package).and_return(['amd64', 'i386'])
    expect(package.architectures).to eq(['amd64', 'i386'])
  end

  it 'queries repository for suites' do
    expect(repository).to receive(:suites_for).with(package).and_return(['unstable', 'experimental'])
    expect(package.suites).to eq(['unstable', 'experimental'])
  end

  it 'queries repository for status' do
    status = double
    expect(repository).to receive(:status_for).with(package).and_return(status)
    expect(package.status).to be(status)
  end

  it 'queries repository for news' do
    news = double
    expect(repository).to receive(:news_for).with(package).and_return(news)
    expect(package.news).to be(news)
  end

  it 'detects if it has a failure' do
    expect(package).to receive(:failures).and_return(['unstable/amd64'])
    expect(package.failures).to eq(['unstable/amd64'])

    expect(package).to receive(:failures).and_return(nil)
    expect(package.failures).to eq(nil)
  end

  it 'detects if it has temporary failures' do
    status = Set.new

    first_status = Debci::Status.new
    first_status.suite = 'unstable'
    first_status.architecture = 'amd64'
    first_status.status = :tmpfail

    second_status = Debci::Status.new
    second_status.suite = 'unstable'
    second_status.architecture = 'i386'
    second_status.status = :pass

    status << first_status << second_status

    allow(repository).to receive(:status_for).with(package).and_return(status)
    expect(package.status).to eq(status)

    tmpfail = package.tmpfail

    expect(tmpfail).to include("unstable/amd64")
    expect(tmpfail).to_not include("unstable/i386")
  end

  it 'converts to string' do
    expect(String(package)).to eq(package.name)
  end

  it 'has a prefix' do
    expect(Debci::Package.new('rake').prefix).to eq('r')
  end

  it 'has a prefix (lib*)' do
    expect(Debci::Package.new('libreoffice').prefix).to eq('libr')
  end

  it 'may be blacklisted' do
    pkg = Debci::Package.new('mypkg')
    allow(Debci.blacklist).to receive(:include?).with(pkg).and_return(true)
    expect(pkg).to be_blacklisted
  end

end

==> debci_1.5.1.tar.xz: debci-1.5.1/spec/debci/package_spec.rb <==
require 'debci/package'
require 'debci/status'

describe Debci::Package do

  let(:repository) { double }

  let(:package) do
    Debci::Package.new('rake', repository)
  end

  it 'queries repository for architectures' do
    expect(repository).to receive(:architectures_for).with(package).and_return(['amd64', 'i386'])
    expect(package.architectures).to eq(['amd64', 'i386'])
  end

  it 'queries repository for suites' do
    expect(repository).to receive(:suites_for).with(package).and_return(['unstable', 'experimental'])
    expect(package.suites).to eq(['unstable', 'experimental'])
  end

  it 'queries repository for status' do
    status = double
    expect(repository).to receive(:status_for).with(package).and_return(status)
    expect(package.status).to be(status)
  end

  it 'queries repository for news' do
    news = double
    expect(repository).to receive(:news_for).with(package).and_return(news)
    expect(package.news).to be(news)
  end

  it 'detects if it has failures and temporary failures' do
    status = Set.new

    tmpfail_status = Debci::Status.new
    tmpfail_status.suite = 'unstable'
    tmpfail_status.architecture = 'amd64'
    tmpfail_status.status = :tmpfail

    pass_status = Debci::Status.new
    pass_status.suite = 'unstable'
    pass_status.architecture = 'i386'
    pass_status.status = :pass

    fail_status = Debci::Status.new
    fail_status.suite = 'unstable'
    fail_status.architecture = 'i386'
    fail_status.status = :fail

    status << tmpfail_status << pass_status << fail_status

    allow(repository).to receive(:status_for).with(package).and_return(status)
    expect(package.status).to eq(status)

    expect(package.tmpfail).to eq([tmpfail_status])

    expect(package.failures).to eq([fail_status])
  end

  it 'converts to string' do
    expect(String(package)).to eq(package.name)
  end

  it 'has a prefix' do
    expect(Debci::Package.new('rake').prefix).to eq('r')
  end

  it 'has a prefix (lib*)' do
    expect(Debci::Package.new('libreoffice').prefix).to eq('libr')
  end

  it 'may be blacklisted' do
    pkg = Debci::Package.new('mypkg')
    allow(Debci.blacklist).to receive(:include?).with(pkg).and_return(true)
    expect(pkg).to be_blacklisted
  end

end
